@@ -51,6 +51,18 @@ def parseOptions():
         args.info=True
         args.reg=True
 
+    # Set info, in case no other action is set
+    if args.deregister_from_service or\
+        args.register_for_service or\
+        args.activate or\
+        args.deactivate or\
+        args.grp or\
+        args.reg or\
+        args.ssh:
+            pass
+    else:
+        args.info = True
+
     return args
 
 # reparse args on import
