@@ -4,14 +4,14 @@
 # vim: tw=100
 # pylint: disable=bad-continuation, invalid-name, superfluous-parens
 # pylint: disable=bad-whitespace, mixed-indentation
-# pylint: disable=redefined-outer-name, logging-not-lazy, logging-format-interpolation
+# pylint: disable=redefined-outer-name, 
+# pylint: logging-fstring-interpolation, logging-not-lazy, logging-format-interpolation
 
 import os
 import sys
 import json
 import logging
 import urllib.parse as ul
-import requests
 
 from regapp_tools.parse_args import args
 from regapp_tools.bwidmtools import external_id_from_subiss, get_external_id_from_username
@@ -19,7 +19,6 @@ from regapp_tools.bwidmtools import get_username_from_external_id, get_sshkey_fr
 from regapp_tools.bwidmtools import get_userinfo_from_external_id, get_user_registrations_from_external_id
 from regapp_tools.bwidmtools import deregister_external_id_from_service, register_external_id_from_service
 from regapp_tools.bwidmtools import get_list_of_all_users, deactivate_user, activate_user
-from regapp_tools.bwidmconnection import BwIdmConnection
 from regapp_tools.bwidm_user import User, Registry
 
 
@@ -42,7 +41,7 @@ logger = logging.getLogger(__name__)
 
 
 # def get_sshkeys(externalId='hdf_61230996-664f-4422-9caa-76cf086f0d6c@unity-hdf'):
-def display_info():
+def do_action():
     '''get info from externalId'''
     ##### in case we need user access:
 
@@ -68,17 +67,17 @@ def display_info():
         username = ""
         parameter = args.username[0]
         if len(parameter.split('@')) == 2: # we got sub@iss or external_id
-            logger.info("sub@iss or external_id")
+            logger.debug("sub@iss or external_id")
             external_id = external_id_from_subiss(sub_iss=parameter)
             # external_id = "d7a53cbe3e966c53ac64fde7355956560282158ecac8f3d2c770b474862f4756%40egi.eu@https%3A%2F%2Faai.egi.eu%2Foidc%2F"
             # logger.info(F"enforced external id: {external_id}")
-            logger.info(F"actual external id: {external_id}")
+            logger.debug(F"actual external id: {external_id}")
 
             username = get_username_from_external_id(external_id)
 
         elif len(parameter.split('@')) == 1: # we got a username
             external_id = get_external_id_from_username(parameter)
-            logger.info(F"actual external id: {external_id} (from username: {parameter})")
+            logger.debug(F"actual external id: {external_id} (from username: {parameter})")
             username = parameter
         else:
             logger.error(F"The provided parameter '{args.username}' is neither a username nor a sub@iss")
@@ -96,7 +95,7 @@ def display_info():
             iss = ""
     # if args.externalid is not None:
     #     external_id = args.externalid
-    logger.info(F"actual external id: {external_id}")
+    logger.debug(F"actual external id: {external_id}")
 
     
     ##### actions on users
@@ -167,7 +166,8 @@ def display_info():
         print (sshkeys)
 def main():
     '''Main Program'''
-    display_info()
+    if args.username != []:
+        do_action()
     return 0
 
 
